#!/bin/sh
# 
# test the tools

DIR=/tmp/

/bin/rm -f /tmp/blank.aff /tmp/blank.iso
/bin/rm -f agent.pem deskclerk.pem archives.pem random.*

echo === MAKING THE TEST FILES ===
dd if=/dev/zero of=/tmp/blank.iso bs=65536 count=100
./afconvert /tmp/blank.iso

dd if=/dev/urandom of=random.iso bs=65536 count=120
dd if=/dev/zero of=r2.iso bs=65536 count=120
cat r2.iso >> random.iso
rm r2.iso
touch r3.iso
for fn in /usr/share/dict/* ; do cat $fn >> r3.iso ; done
for i in `yes | head -50` ; do cat r3.iso >> random.iso ; done
rm r3.iso

echo === Putting a new metadata segment into blank.aff  ===
./afsegment -ssegname=testseg1 /tmp/blank.aff
if [ x"testseg1" = x`./afsegment -p segname /tmp/blank.aff` ] ; then 
  echo afsegment worked!
else
  echo afsegment does not work properly
  exit 1
fi

echo ==== AFSIGN TEST ===
echo Making X.509 keys

openssl req -x509 -newkey rsa:1024 -keyout agent.pem -out agent.pem -nodes -subj "/C=US/ST=California/L=Monterey/O=Country Govt./OU=Sherif Dept/CN=Mr. Investigator/emailAddress=mr@investiations.com"

openssl req -x509 -newkey rsa:1024 -keyout deskclerk.pem -out deskclerk.pem -nodes -subj "/C=US/ST=California/L=San Francisco/O=State Police/OU=Forensics/CN=Ms. Desk Clerk/emailAddress=deskclerk@investiations.com"

openssl req -x509 -newkey rsa:1024 -keyout archives.pem -out archives.pem -nodes -subj "/C=US/ST=DC/L=Washington/O=Archives/OU=Electronic/CN=Dr. Librarian/emailAddress=bigbits@investiations.com"

echo Making an AFF file to sign

./afcopy random.iso signed.aff
if ! ./afsign -s agent.pem signed.aff ; then echo afsign failed ; exit 1 ; fi 
if ! ./afverify signed.aff ; then echo afverify failed ; exit 1 ; fi ; 

echo Signature test 1 passed

echo Testing chain-of-custody signatures

if ! ./afcopy -z -s agent.pem random.iso random.aff ; then exit 1; fi
if ! ./afinfo -a random.aff ; then exit 1 ; fi
if ! ./afcompare random.iso random.aff ; then exit 1 ; fi
if ! ./afverify random.aff ; then exit 1 ; fi

echo
echo Making the second generation copy
echo "This copy was made by desk clerk" | ./afcopy -z -s deskclerk.pem -n random.aff random2.aff
if ! ./afinfo -a random2.aff ; then exit 1 ; fi
if ! ./afcompare random.iso random2.aff ; then exit 1 ; fi
if ! ./afverify random2.aff ; then exit 1 ; fi
echo
@echo Making the third generation copy
echo "This copy was made by the archives" | ./afcopy -z -s archives.pem -n random2.aff random3.aff
if ! ./afinfo -a random3.aff ; then exit 1 ; fi
if ! ./afcompare random.iso random3.aff ; then exit 1 ; fi
if ! ./afverify random3.aff ; then exit 1 ; fi

echo
echo Test of afrecover to recover based on the parity 
echo parity page will be kept in random.afm
if ! ./afsign -s agent.pem random.iso ; then exit 1 ; fi
if ! ./afverify random.afm ; then exit 1 ; fi
openssl md5 < random.iso | tee random.iso.md5.1
dd if=/dev/urandom of=random.iso count=1 skip=1 conv=notrunc
if ! ./afrecover random.afm ; then exit 1 ; fi
if ! ./afverify random.afm ; then exit 1 ; fi
openssl md5 < random.iso | tee random.iso.md5.2
if ! diff random.iso.md5.1 random.iso.md5.1 ; then exit 1 ; fi
/bin/rm -f random.iso.md5.?


echo All tests passed successfully
echo Erasing temporary files.
rm -f agent.pem archives.pem deskclerk.pem random.aff random.afm random.iso random2.aff random3.aff signed.aff
exit 0

